:py:mod:`piel.models.physical.geometry`
=======================================

.. py:module:: piel.models.physical.geometry


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.physical.geometry.calculate_cross_sectional_area_m2



.. py:function:: calculate_cross_sectional_area_m2(diameter_m: float) -> float

   Calculates the cross sectional area of a circle in meters squared.

   :param diameter_m: Diameter of the circle in meters.
   :type diameter_m: float

   :returns: Cross sectional area in meters squared.
   :rtype: float
